summaryrefslogtreecommitdiffstats
path: root/source/World.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'source/World.cpp')
-rw-r--r--source/World.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/source/World.cpp b/source/World.cpp
index 97b5a2b0e..2a73eb7ea 100644
--- a/source/World.cpp
+++ b/source/World.cpp
@@ -1325,11 +1325,11 @@ void cWorld::SpawnItemPickups(const cItems & a_Pickups, double a_BlockX, double
-void cWorld::SpawnPrimedTNT(double a_X, double a_Y, double a_Z, float a_FuseTimeInSec)
+void cWorld::SpawnPrimedTNT(double a_X, double a_Y, double a_Z, float a_FuseTimeInSec, double a_InitialVelocityCoeff)
{
cTNTEntity * TNT = new cTNTEntity(a_X, a_Y, a_Z, a_FuseTimeInSec);
TNT->Initialize(this);
// TODO: Add a bit of speed in horiz and vert axes
}
@@ -1325,11 +1325,11 @@ void cWorld::SpawnItemPickups(const cItems & a_Pickups, double a_BlockX, double
cTNTEntity * TNT = new cTNTEntity(a_X, a_Y, a_Z, a_FuseTimeInSec);
TNT->Initialize(this);
- // TODO: Add a bit of speed in horiz and vert axes
+ // TODO: Add a bit of speed in horiz and vert axes, based on the a_InitialVelocityCoeff
}